#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctemplates
version:              0.11.0.1
visibility:           public
id:                   doctemplates-0.11.0.1-8iqu0om3Yr73yc51U44NM5
key:                  doctemplates-0.11.0.1-8iqu0om3Yr73yc51U44NM5
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  122908af234720c9449d1cf3f56c3740
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11.0.1-8iqu0om3Yr73yc51U44NM5
depends:
    aeson-2.2.1.0-5nVyzmxvbxuJpsKX5ABORi base-4.18.2.1 containers-0.6.7
    doclayout-0.5-D8YLzlnNBY416sfCQweyHr filepath-1.4.300.1 mtl-2.3.1
    parsec-3.1.16.1 safe-0.3.21-FJE0Z4qRJok8xv9ZQW2bh3
    scientific-0.3.8.1-EdxyBX7wnjV6bwZytH2Jbi text-2.0.2
    text-conversions-0.3.1.1-4WQDmUNv6ot7xH2oGXQuSr
    vector-0.13.2.0-91lzNiZgjgOBDn02pUIYXJ

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

